'
' keyconfig.vbs
' SSL keystore configuration utility
'
' Copyright (c) 2013 SAS
'

' variables
version = "1.0"
usage   = "keyconfig <command> <options>"

' command line or GUI? 
If InStr(UCase(WScript.FullName), "CSCRIPT") Then
    isGUI = false
Else
    isGUI = true
End If

' return true if path is absolute
Function isAbs(path)
    isAbs = false
    c1 = Mid(path, 1, 1)
    If c1 = "\" Or c1 = "/" Then
        ' UNC path or abs path on current volume
        isAbs = true
    Else 
        c2 = Mid(path, 2, 2)
        If c2 = ":\" Then
            ' C:\foo\bar
            isAbs = true
        End If
    End If
End Function

' user input
Function Question(prompt)
    If isGUI = false Then
        WSCript.StdOut.Write prompt & ": "
        Question = WSCript.StdIn.ReadLine
    Else
        Question = InputBox(prompt)
    End If
End Function

' find root of installation 
Set fso = CreateObject("Scripting.FileSystemObject")
bindir = fso.GetFile(WScript.ScriptFullName).ParentFolder
home = bindir & "\..\"
datadir = home & "data\"
etcdir = home & "etc\"
libdir = home & "lib\"
vardir = home & "var\"

' file locations
cfgFile = etcdir & "\webstudio.cfg"

' Read registry for Java information
Dim SysVarReg, javaCurVer, javaHome, javaRT, java32Bit
java32Bit = false
Set SysVarReg = WScript.CreateObject("WScript.Shell")

' Turn error reporting off
On Error Resume Next
Err.Clear
javaCurVer = SysVarReg.RegRead("HKLM\Software\JavaSoft\Java Runtime Environment\CurrentVersion")
If Err <> 0 Then
    ' Check the 32bit version on a 64bit machine
    Err.Clear
    javaCurVer = SysVarReg.RegRead("HKLM\Software\Wow6432Node\JavaSoft\Java Runtime Environment\CurrentVersion")
    If Err <> 0 Then
        ' Did not find the key and exit
        ShowError "Java is not installed on this machine."
        WScript.Quit 1
    Else
        java32Bit = true
    End If
End If

Dim javaSoft
If java32Bit <> true Then
    javaSoft = "JavaSoft"
Else
    javaSoft = "Wow6432Node\JavaSoft"
End If
javaHome = SysVarReg.RegRead("HKLM\Software\" & javaSoft & "\Java Runtime Environment\" & javaCurVer & "\JavaHome")
javaRT = SysVarReg.RegRead("HKLM\Software\" & javaSoft & "\Java Runtime Environment\" & javaCurVer & "\RuntimeLib")

' Turn error reporting back on
On Error Goto 0

' Find keystore location from configuration file
Set file = fso.GetFile(cfgFile)
Set stream = file.OpenAsTextStream(1, -1)
While Not stream.AtEndOfStream 
    line = stream.ReadLine
    If Left(line, 1) <> "#" Then
    ' not a comment
        fields = Split(line, "=")
        If UBound(fields) > 0 Then
            ' key=value line
            key = Trim(fields(0))
            value = Trim(fields(1))
            If (LCase(key) = "key_store_path") Then
                keyStore = value
            End If
        End If
    End If
Wend

' determine server's job directory
If keyStore = "" Then
    keyStore = vardir & "\webstudio.keystore"
End If

' Setup environment
Set shell = WScript.CreateObject("WScript.Shell")

' Setup keytool command
keyTool = """" & javaHome & "\bin\keytool.exe"""

' process command line
If WScript.Arguments.Count < 1 Then
    WScript.Echo usage
    WScript.Echo "(For more information type: keyconfig help)"
    WScript.Quit 1
End If
cmdName = WScript.Arguments(0)

' Turn error reporting off
On Error Resume Next

' handle commands
If cmdName = "create" Then
    ' Check command line options
    If WScript.Arguments.Count >= 2 Then
        If (StrComp(WScript.Arguments(1), "-ks",1) = 0) Then
            keyStore = WScript.Arguments(2)
        End If
    End If
    cmd =  keyTool & " -genkeypair -keystore """ & keyStore & """ -validity 365 -keyalg RSA -alias jetty"
    ' WScript.Echo cmd
    shell.Run("%comspec% /C """ & cmd & """"), 5, True
ElseIf cmdName = "request" Then
    ' Check command line options
    If WSCript.Arguments.Count < 2 Then
        WScript.Echo "The option for the 'request' command is -file and optionally -ks."
        WSCript.Quit 1
    End If
    ' keystore
    If (StrComp(WScript.Arguments(1), "-file",1) = 0) Then
        certReqFile = WScript.Arguments(2)
    Else
        ShowError "You did not supply a cert request file with the -file option."
        WSCript.Quit 1
    End If
    If WScript.Arguments.Count >= 4 Then
        If (StrComp(WScript.Arguments(3), "-ks",1) = 0) Then
            keyStore = WScript.Arguments(4)
        End If
    End If
    cmd =  keyTool & " -certreq -keystore """ & keyStore & """ -alias jetty -file """ & certReqFile & """"
    ' WScript.Echo cmd
    shell.Run("%comspec% /C """ & cmd & """"), 5, True
ElseIf cmdName = "import" Then
    ' Check command line options
    If WSCript.Arguments.Count < 2 Then
        WScript.Echo "The option for the 'import' command is -file and optionally -ks."
        WSCript.Quit 1
    End If
    ' keystore
    If (StrComp(WScript.Arguments(1), "-file",1) = 0) Then
        certFile = WScript.Arguments(2)
    Else
        ShowError "You did not supply a certificate file with the -cert option."
        WSCript.Quit 1
    End If
    if WAcript.Arguments.Count >= 4 Then
        If (StrComp(WScript.Arguments(3), "-ks",1) = 0) Then
            keyStore = WScript.Arguments(4)
        End If
    End If
    cmd =  keyTool & " -importcert -keystore """ & keyStore & """ -alias jetty -file """ & certFile & """"
    ' WScript.Echo cmd
    shell.Run("%comspec% /C """ & cmd & """"), 5, True
ElseIf cmdName = "help" Then
    WScript.Echo usage
    WScript.Echo "Commands:"
    WScript.Echo "    create     Create the keystore"
    WSCript.Echo "               [-ks <keystore file>]"
    WScript.Echo "    request    Generate the CA request"
    WScript.Echo "                -file <certificate request file>"
    WScript.Echo "               [-ks <keystore file>]"
    WScript.Echo "    import     Import the CA approved certificate"
    WSCript.Echo "                -cert <certificate being imported>"
    WScript.Echo "               [-ks <keystore file>]"
    WScript.Echo "    help       display this message"
    WScript.Echo "    version    display version information"
    WScript.Echo " "
    WScript.Quit 0
ElseIf cmdName = "version" Then
    WScript.Echo version
    WScript.Quit 0
Else
    WScript.Echo "ERROR: unknown command '" & cmdName & "'."
    WScript.Echo "(Run 'keyconfig help' for a list of commands and options.)"
    WScript.Quit 1
End If

' Turn error reporting back on
On Error Goto 0


